/**
 * @file Click_Pollution_WSP2110.c
 * @brief <h2> Pollution click Example </h2>
 *
 * @par
 * Example for <a href="http://www.mikroe.com">MikroElektronika's</a>
 * Pollution click board.
 *
 *
 *
 ******************************************************************************/

/**
 * @page        Example
 * @date        15 Nov 2016
 * @author      Branislav Marton
 * @copyright   GNU Public License
 * @version     1.0.0 - Initial testing and verification
 */

/**
 * @page TEST_CFG Test Configurations
 *
 * ### Test configuration STM : ###
 * @par
 * -<b> MCU           </b> :    ATMEGA32
 * -<b> Dev. Board    </b> :    EasyAVR v7
 * -<b> Ext. Modules  </b> :    Pollution click board, LCD
 * -<b> SW            </b> :    mikroC PRO for AVR v6.1.2
 *
 */

/**
 * @page Dev. board setup
 *
 * 1) Put Pollution click in mikroBUS 1 slot.
 * 2) Button press level for PD set to GND.
 * 3) Set pull-up for PD7.
 */

#ifndef POLLUTION_H
#define POLLUTION_H

/******************************************************************************
* Includes
*******************************************************************************/
#include <stdint.h>

/******************************************************************************
* Preprocessors
*******************************************************************************/


/******************************************************************************
* Typedefs
*******************************************************************************/

/******************************************************************************
* Variable Definitions
*******************************************************************************/

/******************************************************************************
* Private Functions
*******************************************************************************/

/******************************************************************************
* Public Functions
*******************************************************************************/
float measure_v_load( void );

float sensor_resistance(float v_load, float r_load);
float load_resistance(float v_load, float r_load);

float ratio_to_ppm(float ratio);
/*************** END OF FUNCTIONS *********************************************/

#endif // !POLLUTION_H