/**
 * @file Click_Pollution_WSP2110.c
 * @brief <h2> Pollution click Example </h2>
 *
 * @par
 * Example for <a href="http://www.mikroe.com">MikroElektronika's</a>
 * Pollution click board.
 *
 *
 *
 ******************************************************************************/

/**
 * @page        Example
 * @date        15 Nov 2016
 * @author      Branislav Marton
 * @copyright   GNU Public License
 * @version     1.0.0 - Initial testing and verification
 */

/**
 * @page TEST_CFG Test Configurations
 *
 * ### Test configuration STM : ###
 * @par
 * -<b> MCU           </b> :    ATMEGA32
 * -<b> Dev. Board    </b> :    EasyAVR v7
 * -<b> Ext. Modules  </b> :    Pollution click board, LCD
 * -<b> SW            </b> :    mikroC PRO for AVR v6.1.2
 *
 */

/**
 * @page Dev. board setup
 *
 * 1) Put Pollution click in mikroBUS 1 slot.
 * 2) Button press level for PD set to GND.
 * 3) Set pull-up for PD7.
 */

/******************************************************************************
* Includes
*******************************************************************************/
#include "pollution_gui.h"

/******************************************************************************
* Preprocessors
*******************************************************************************/


/******************************************************************************
* Typedefs
*******************************************************************************/

/******************************************************************************
* Variable Definitions
*******************************************************************************/
static char str_buffer[16];

static char inequality_sign = ' ';

/******************************************************************************
* Function Prototypes
*******************************************************************************/

/******************************************************************************
* Private Functions
*******************************************************************************/

/******************************************************************************
* Public Functions
*******************************************************************************/

/***************************************************************************//**
 */
void gui_init()
{
    LCD_Init();
    Lcd_Cmd(_LCD_CLEAR);
    Lcd_Cmd(_LCD_CURSOR_OFF);
}

/***************************************************************************//**
 *  Prints 'calibration' page with isntructions.
 */
void gui_print_calibration_page()
{
    Lcd_Out(1, 1, "Calibration");
    Lcd_Out(2, 1, "V(load) = ");
}

/***************************************************************************//**
 *  Prints 'Adjust sensitivity' page with isntructions.
 */
void gui_print_adjust_load_page()
{
    Lcd_Out(1, 1, "Sensitivity");
    Lcd_Out(2, 1, "R(load) = ");
}

/***************************************************************************//**
 *   Prints 'Measure' page.
 */
void gui_print_measure_page()
{ 
    Lcd_Out(1, 1, "Measure");
    Lcd_Out(2, 1, "ppm = ");
}

/***************************************************************************//**
 *   Clears page area.
 */
void gui_clear_page()
{
    Lcd_Cmd(_LCD_CLEAR);
}

/***************************************************************************//**
 *  Refresh value on page.
 *  \param value New value to display.
 *  \param old_value Latest displayed value.
 *  \param x Text X position.
 *  \param y Text Y position.
 *  \param format An sprintf format.
 *  \return Return value.
 */
float gui_refresh_value(float value, float old_value, uint16_t x, uint16_t y,
                    const char* format)
{
    if(value != old_value)
    {
        sprintf(str_buffer, format, value);
        Lcd_Out(2, 12, str_buffer);
    }

    return value;
}


/***************************************************************************//**
 *  Updates inequality sign on display.
 *  \param value PPM value to compare.
 */
void gui_update_inequality_sign(float value)
{
    char new_inequality_sign;
    new_inequality_sign = (value == 50) ? '>' : ((value == 1) ? '<' : '=');

    if(new_inequality_sign != inequality_sign)
    {
        Lcd_Chr(2, 5, new_inequality_sign);

        inequality_sign = new_inequality_sign;
    }    
}

/*************** END OF FUNCTIONS *********************************************/