/**
 * @file Click_Pollution_WSP2110.c
 * @brief <h2> Pollution click Example </h2>
 *
 * @par
 * Example for <a href="http://www.mikroe.com">MikroElektronika's</a>
 * Pollution click board.
 *
 *
 *
 ******************************************************************************/

/**
 * @page        Example
 * @date        15 Nov 2016
 * @author      Branislav Marton
 * @copyright   GNU Public License
 * @version     1.0.0 - Initial testing and verification
 */

/**
 * @page TEST_CFG Test Configurations
 *
 * ### Test configuration STM : ###
 * @par
 * -<b> MCU           </b> :    ATMEGA32
 * -<b> Dev. Board    </b> :    EasyAVR v7
 * -<b> Ext. Modules  </b> :    Pollution click board, LCD
 * -<b> SW            </b> :    mikroC PRO for AVR v6.1.2
 *
 */

/**
 * @page Dev. board setup
 *
 * 1) Put Pollution click in mikroBUS 1 slot.
 * 2) Button press level for PD set to GND.
 * 3) Set pull-up for PD7.
 */

#ifndef POLLUTION_GUI_H
#define POLLUTION_GUI_H

/******************************************************************************
* Includes
*******************************************************************************/
#include <stdint.h>


/******************************************************************************
* Preprocessors
*******************************************************************************/


/******************************************************************************
* Typedefs
*******************************************************************************/

/******************************************************************************
* Variable Definitions
*******************************************************************************/

/******************************************************************************
* Private Functions
*******************************************************************************/

/******************************************************************************
* Public Functions
*******************************************************************************/
void gui_init();
void gui_print_calibration_page();
void gui_print_adjust_load_page();
void gui_print_measure_page();

void gui_clear_page();

float gui_refresh_value(
    float value, 
    float old_value, 
    uint16_t x, 
    uint16_t y, 
    const char* format
);

void gui_update_inequality_sign(float value);

/*************** END OF FUNCTIONS *********************************************/

#endif // !POLLUTION_GUI_H